@@ -50,7 +50,7 @@ sub import {
 
 1;
 
-our $VERSION = '0.0193';    # VERSION
+our $VERSION = '0.0194';    # VERSION
 
 # ABSTRACT: Evo - the next generation component-oriented development framework
 
@@ -66,7 +66,7 @@ Evo - Evo - the next generation component-oriented development framework
 
 =head1 VERSION
 
-version 0.0193
+version 0.0194
 
 =head1 DESCRIPTION
 
@@ -85,7 +85,7 @@ Post modern component oriented programming L<Evo::Comp> instead of OO
 (no docs yet) Fast Event-Loop L<Evo::Loop> with unique feature zones (Not ready)
 
 =item *
-Fast non recursive L<Evo::Promise>, 100% "Promise/Spec A" compatible
+Fast non recursive L<Evo::Promise>, 100% "Promise/Spec A" compatible. + Nice syntax via experimental L<Evo::Prm>
 
 =item *
 Interesting L<Evo::Realm> design pattern, which is as handy as "Singleton" but without Sintleton's flaws. Testable and mockable alternative of the global class
