@@ -16,14 +16,15 @@ sub is_fulfilled_with($v, $p) : Export {
   croak unless defined wantarray;
   return unless $p->d_settled && $p->{state} eq FULFILLED;
   my $dv = $p->d_v;
-  return defined $dv ? $v eq $dv : !defined $dv;
+
+  return defined $dv ? $v eq $dv : !defined $v;
 }
 
 sub is_rejected_with($v, $p) : Export {
   croak unless defined wantarray;
   return unless $p->d_settled && $p->{state} eq REJECTED;
   my $dv = $p->d_v;
-  return defined $dv ? $v eq $dv : !defined $dv;
+  return defined $dv ? $v eq $dv : !defined $v;
 }
 
 sub promise_resolve($v) : Export {
@@ -100,7 +101,7 @@ Evo::Promise::Util
 
 =head1 VERSION
 
-version 0.0193
+version 0.0194
 
 =head1 AUTHOR
 
